---
title: Welcome to Mophidian
---

# Welcome!

Edit the `README.md` in the `pages/` directory to change this page. You may also add your own `page.phml` file to replace the README.md. You may also edit the `layout.phml` file. Careful, as this will have an affect on all pages using that layout.

For more information about about Mophidian and how to use it visit the [docs](https://example.com "Mophidian docs"). If you would like to learn more about the custom markup language `phml` you can see the docs for it [here](https://example.com "phml docs").

Check out this [second page](/sample/)

<Callout>
    **Components work inside of markdown!** *This is due to the fact that the markdown parser also parses html*.
</Callout>

<Callout style="warn">
   If you plan to use components inside of markdown files, using MDX files may help. This will give your IDE the chance to give better syntax highlighting along with component completion. However, the full MDX language is not supported. No javascript inside a MDX file will be processed; instead the MDX file is treated as plain markdown and is only used for IDE support.
</Callout>

<Callout style="danger">
    This project is a work in progress. Error handling and the quality of the library is constantly being imporoved. If you find bugs, feel something is missing, or just want to suggest features drop into the [discord](https://example.com) for support.
</Callout>